==> pysamstats-0.4.6.tar.gz: pysamstats-0.4.6/setup.py <==
from distutils.core import setup
from distutils.extension import Extension
from ast import literal_eval


def get_version(source='pysamstats.pyx'):
    with open(source) as f:
        for line in f:
            if line.startswith('VERSION'):
                return literal_eval(line.partition('=')[2].lstrip())
    raise ValueError("VERSION not found")


def get_include():
    try:
        import pysam
    except ImportError:
        pass
    else:
        return pysam.get_include()


def get_defines():
    try:
        import pysam
    except ImportError:
        pass
    else:
        return pysam.get_defines()


setup(
    name='pysamstats',
    version=get_version(),
    author='Alistair Miles',
    author_email='alimanfoo@googlemail.com',
    url='https://github.com/alimanfoo/pysamstats',
    license='MIT Licenses',
    description='A Python utility for calculating statistics per genome position based on pileups from a SAM or BAM file.',
    scripts=['pysamstats'],
    ext_modules = [Extension('pysamstats', 
                             ['pysamstats.c'], 
                             include_dirs=get_include(),
                             define_macros=get_defines()),
                   ],
    classifiers=['Intended Audience :: Developers',
                 'License :: OSI Approved :: MIT License',
                 'Programming Language :: Python',
                 'Topic :: Software Development :: Libraries :: Python Modules'
                 ],
    install_requires=['pysam>=0.7.4', 'numpy>=1.6'],
)

==> pysamstats-0.4.8.tar.gz: pysamstats-0.4.8/setup.py <==
from distutils.core import setup
from distutils.extension import Extension
from ast import literal_eval


try:
    import pysam
    from Cython.Distutils import build_ext # Cython should be installed via pysam
except ImportError:
    raise Exception('please install pysam first, e.g.: pip install --upgrade pysam pysamstats')


def get_version(source='pysamstats.pyx'):
    with open(source) as f:
        for line in f:
            if line.startswith('__version__'):
                return literal_eval(line.partition('=')[2].lstrip())
    raise ValueError("__version__ not found")


setup(
    name='pysamstats',
    version=get_version(),
    author='Alistair Miles',
    author_email='alimanfoo@googlemail.com',
    url='https://github.com/alimanfoo/pysamstats',
    license='MIT Licenses',
    description='A Python utility for calculating statistics per genome position based on pileups from a SAM or BAM file.',
    scripts=['pysamstats'],
    cmdclass = {'build_ext': build_ext},
    ext_modules = [Extension('pysamstats', 
                             ['pysamstats.pyx'], 
                             include_dirs=pysam.get_include(),
                             define_macros=pysam.get_defines()),
                   ],
    classifiers=['Intended Audience :: Developers',
                 'License :: OSI Approved :: MIT License',
                 'Programming Language :: Python',
                 'Topic :: Software Development :: Libraries :: Python Modules'
                 ],
    install_requires=['pysam>=0.7.4', 'numpy>=1.6'],
)
